@@ -10,6 +10,8 @@
 #ifndef GMIC_QT_FILTERTEXTTRANSLATOR_H
 #define GMIC_QT_FILTERTEXTTRANSLATOR_H
 
+#include <QByteArray>
+#include <QCoreApplication>
 #include <QDebug>
 #include <QObject>
 #include <QString>
@@ -23,18 +25,12 @@ class FilterTextTranslator : public QObject {
   Q_OBJECT
 public:
   FilterTextTranslator() = delete;
-
-  inline static QString translate(const QString & str);
+  static QString translate(const QString & str);
 
 protected:
 private:
 };
 
-QString FilterTextTranslator::translate(const QString & str)
-{
-  return tr(str.toUtf8());
-}
-
 } // namespace GmicQt
 
 #endif // GMIC_QT_FILTERTEXTTRANSLATOR_H
