@@ -27,14 +27,15 @@
 #include <iostream>
 #include "FilterParameters/AbstractParameter.h"
 #include "GmicStdlib.h"
-#include "ImageConverter.h"
 #include "Logger.h"
-#include "Utils.h"
+#include "Misc.h"
 #include "gmic.h"
-using namespace cimg_library;
 
-FilterThread::FilterThread(QObject * parent, const QString & name, const QString & command, const QString & arguments, const QString & environment, GmicQt::OutputMessageMode mode)
-    : QThread(parent), _command(command), _arguments(arguments), _environment(environment), _images(new cimg_library::CImgList<float>), _imageNames(new cimg_library::CImgList<char>), _name(name),
+namespace GmicQt
+{
+
+FilterThread::FilterThread(QObject * parent, const QString & command, const QString & arguments, const QString & environment, OutputMessageMode mode)
+    : QThread(parent), _command(command), _arguments(arguments), _environment(environment), _images(new cimg_library::CImgList<float>), _imageNames(new cimg_library::CImgList<char>),
       _messageMode(mode)
 {
   _gmicAbort = false;
@@ -52,11 +53,6 @@ FilterThread::~FilterThread()
   delete _imageNames;
 }
 
-void FilterThread::setArguments(const QString & str)
-{
-  _arguments = str;
-}
-
 void FilterThread::setImageNames(const cimg_library::CImgList<char> & imageNames)
 {
   *_imageNames = imageNames;
@@ -94,9 +90,9 @@ QStringList FilterThread::status2StringList(const QString & status)
     // TRACE << "Warning: Incorrect status syntax " << status;
     return QStringList();
   }
-  QList<QString> list = statusRegExp.cap(1).split(statusSeparatorRegExp);
+  QStringList list = statusRegExp.cap(1).split(statusSeparatorRegExp);
   if (!list.isEmpty()) {
-    QList<QString>::iterator it = list.begin();
+    QStringList::iterator it = list.begin();
     while (it != list.end()) {
       QByteArray array = it->toLocal8Bit();
       gmic::strreplace_fw(array.data());
@@ -117,6 +113,7 @@ QList<int> FilterThread::status2Visibilities(const QString & status)
     // TRACE << "Incorrect status syntax " << status;
     return QList<int>();
   }
+
   QByteArray ba = status.toLocal8Bit();
   const char * pc = ba.constData();
   const char * limit = pc + ba.size();
@@ -125,11 +122,10 @@ QList<int> FilterThread::status2Visibilities(const QString & status)
   while (pc < limit) {
     if (*pc == gmic_rbrace) {
       if ((pc < limit - 2) && pc[1] == '_' && pc[2] >= '0' && pc[2] <= '2' && (!pc[3] || pc[3] == gmic_lbrace)) {
-        auto visibilityState = static_cast<AbstractParameter::VisibilityState>(pc[2] - '0');
-        result.push_back(visibilityState);
+        result.push_back(pc[2] - '0'); // AbstractParameter::VisibilityState
         pc += 3;
       } else if (!pc[1] || (pc[1] == gmic_lbrace)) {
-        result.push_back(AbstractParameter::UnspecifiedVisibilityState);
+        result.push_back((int)AbstractParameter::VisibilityState::Unspecified);
         ++pc;
       } else {
         // TRACE << "Ignoring status" << qPrintable(status);
@@ -169,7 +165,7 @@ bool FilterThread::aborted() const
 
 int FilterThread::duration() const
 {
-  return _startTime.elapsed();
+  return static_cast<int>(_startTime.elapsed());
 }
 
 float FilterThread::progress() const
@@ -177,15 +173,10 @@ float FilterThread::progress() const
   return _gmicProgress;
 }
 
-QString FilterThread::name() const
-{
-  return _name;
-}
-
 QString FilterThread::fullCommand() const
 {
   QString result = _command;
-  GmicQt::appendWithSpace(result, _arguments);
+  appendWithSpace(result, _arguments);
   return result;
 }
 
@@ -206,16 +197,16 @@ void FilterThread::run()
   _failed = false;
   QString fullCommandLine;
   try {
-    fullCommandLine = QString::fromLocal8Bit(GmicQt::commandFromOutputMessageMode(_messageMode));
-    GmicQt::appendWithSpace(fullCommandLine, _command);
-    GmicQt::appendWithSpace(fullCommandLine, _arguments);
+    fullCommandLine = commandFromOutputMessageMode(_messageMode);
+    appendWithSpace(fullCommandLine, _command);
+    appendWithSpace(fullCommandLine, _arguments);
     _gmicAbort = false;
     _gmicProgress = -1;
-    if (_messageMode > GmicQt::Quiet) {
+    if (_messageMode > OutputMessageMode::Quiet) {
       Logger::log(fullCommandLine, _logSuffix, true);
     }
-    gmic gmicInstance(_environment.isEmpty() ? nullptr : QString("%1").arg(_environment).toLocal8Bit().constData(), GmicStdLib::Array.constData(), true);
-    gmicInstance.set_variable("_host", GmicQt::HostApplicationShortname, '=');
+    gmic gmicInstance(_environment.isEmpty() ? nullptr : QString("%1").arg(_environment).toLocal8Bit().constData(), GmicStdLib::Array.constData(), true, nullptr, nullptr, 0.0f);
+    gmicInstance.set_variable("_host", GmicQtHost::ApplicationShortname, '=');
     gmicInstance.set_variable("_tk", "qt", '=');
     gmicInstance.run(fullCommandLine.toLocal8Bit().constData(), *_images, *_imageNames, &_gmicProgress, &_gmicAbort);
     _gmicStatus = gmicInstance.status;
@@ -224,9 +215,11 @@ void FilterThread::run()
     _imageNames->assign();
     const char * message = e.what();
     _errorMessage = message;
-    if (_messageMode > GmicQt::Quiet) {
+    if (_messageMode > OutputMessageMode::Quiet) {
       Logger::error(QString("When running command '%1', this error occurred:\n%2").arg(fullCommandLine).arg(message), true);
     }
     _failed = true;
   }
 }
+
+} // namespace GmicQt
