@@ -23,8 +23,9 @@
  *
  */
 #include "Widgets/ProgressInfoWidget.h"
-#include <QDesktopWidget>
 #include <QFile>
+#include <QGuiApplication>
+#include <QScreen>
 #include "DialogSettings.h"
 #include "GmicProcessor.h"
 #include "IconLoader.h"
@@ -36,10 +37,13 @@
 #include <psapi.h>
 #endif
 
+namespace GmicQt
+{
+
 ProgressInfoWidget::ProgressInfoWidget(QWidget * parent) : QWidget(parent), ui(new Ui::ProgressInfoWidget), _gmicProcessor(nullptr)
 {
   ui->setupUi(this);
-  _mode = GmicProcessingMode;
+  _mode = Mode::GmicProcessing;
   _canceled = false;
   _growing = true;
   setWindowTitle(tr("G'MIC-Qt Plug-in progression"));
@@ -50,8 +54,11 @@ ProgressInfoWidget::ProgressInfoWidget(QWidget * parent) : QWidget(parent), ui(n
   connect(ui->tbCancel, SIGNAL(clicked(bool)), this, SLOT(onCancelClicked()));
   if (!parent) {
     QRect position = frameGeometry();
-    position.moveCenter(QDesktopWidget().availableGeometry().center());
-    move(position.topLeft());
+    QList<QScreen *> screens = QGuiApplication::screens();
+    if (!screens.isEmpty()) {
+      position.moveCenter(screens.front()->geometry().center());
+      move(position.topLeft());
+    }
   }
 
   _showingTimer.setSingleShot(true);
@@ -83,9 +90,9 @@ void ProgressInfoWidget::setGmicProcessor(const GmicProcessor * processor)
 
 void ProgressInfoWidget::onTimeOut()
 {
-  if (_mode == GmicProcessingMode) {
+  if (_mode == Mode::GmicProcessing) {
     updateThreadInformation();
-  } else if (_mode == FiltersUpdateMode) {
+  } else if (_mode == Mode::FiltersUpdate) {
     updateUpdateProgression();
   }
 }
@@ -113,7 +120,7 @@ void ProgressInfoWidget::startFilterThreadAnimationAndShow(bool showCancelButton
   layout()->addWidget(ui->label);
 
   _canceled = false;
-  _mode = GmicProcessingMode;
+  _mode = Mode::GmicProcessing;
   ui->progressBar->setRange(0, 100);
   ui->progressBar->setValue(0);
   ui->progressBar->setInvertedAppearance(false);
@@ -134,7 +141,7 @@ void ProgressInfoWidget::startFiltersUpdateAnimationAndShow()
   layout()->addWidget(ui->tbCancel);
   layout()->addWidget(ui->progressBar);
 
-  _mode = FiltersUpdateMode;
+  _mode = Mode::FiltersUpdate;
   _canceled = false;
   // ui->progressBar->setRange(0, 0);
   ui->progressBar->setValue(AnimationStep);
@@ -238,3 +245,5 @@ void ProgressInfoWidget::updateUpdateProgression()
     }
   }
 }
+
+} // namespace GmicQt
